@@ -2,7 +2,7 @@ import mcpi
 
 from mcpi.vec3 import Vec3
 
-from .creation import Creation
+from .scene import Scene
 from .thing import Thing
 
 
@@ -18,8 +18,8 @@ class BlocksGallery(Thing):
         """
 
         for i in range(1, self.MAX_BLOCK_NUMBER):
-            Creation.server.setBlock(self.position.x + i, self.position.y,
-                                     self.position.z, mcpi.block.Block(i))
+            Scene.server.setBlock(self.position.x + i, self.position.y,
+                                  self.position.z, mcpi.block.Block(i))
 
         self._end_position = Vec3(self.position.x + self.MAX_BLOCK_NUMBER - 1,
                                   self.position.y, self.position.z)
