@@ -4,13 +4,14 @@ from mcthings.thing import Thing
 
 class Sphere(Thing):
 
-    radius = None
+    radius = 5
     """ radius of the Sphere """
+    height = 0
 
     def build(self):
         Scene.drawing.drawSphere(
             self.position.x,
-            self.position.y,
+            self.position.y + self.height - 1,
             self.position.z,
             self.radius,
             self.block)
@@ -21,11 +22,12 @@ class SphereHollow(Thing):
 
     radius = None
     """ radius of the Hollow Sphere """
+    height = 0
 
     def build(self):
         Scene.drawing.drawHollowSphere(
             self.position.x,
-            self.position.y,
+            self.position.y + self.height - 1,
             self.position.z,
             self.radius,
             self.block)
